// ======================================================================
//
// DebugPrint.h
// jeff grills
//
// copyright 1997 origin systems inc
//
// ======================================================================

#ifndef DEBUG_PRINT_H
#define DEBUG_PRINT_H

// ======================================================================
// debug flags

#include "DebugPrintGame.def"

#if USE_DEBUG_PRINT

// ======================================================================
// variables

extern bool *DoNotUseDPrintFlag;
extern bool *DoNotUseDPrintPaused;
extern bool *DoNotUseDPrintLogging;
extern bool *DoNotUseDPrintExplicitLogging;

// ======================================================================
// real functions

#if !COMPILING_DLL

void        DoNotUseDPrintClear(void);
void        DoNotUseDPrint(const char *fmt, ...);

#else

extern void  (*DoNotUseDPrintClear)(void);
extern void  (*DoNotUseDPrint)(const char *fmt, ...);

#endif

// ======================================================================
// inline real functions

inline void DPrintPauseOn(void)
{
	if (DoNotUseDPrintFlag)
		*DoNotUseDPrintPaused = true;
}

inline void DPrintPauseOff(void)
{
	if (DoNotUseDPrintFlag)
		*DoNotUseDPrintPaused = false;
}

inline void DPrintPauseToggle(void)
{
	if (DoNotUseDPrintFlag)
		*DoNotUseDPrintPaused = !*DoNotUseDPrintPaused;
}

inline void DPrintLogOn(void)
{
	if (DoNotUseDPrintFlag)
		*DoNotUseDPrintLogging = true;
}

inline void DPrintLogOff(void)
{
	if (DoNotUseDPrintFlag)
		*DoNotUseDPrintLogging = false;
}

inline void DPrintLogToggle(void)
{
	if (DoNotUseDPrintFlag)
		*DoNotUseDPrintLogging = !*DoNotUseDPrintLogging;
}

inline void DPrintLogNext(void)
{
	if (DoNotUseDPrintFlag)
		*DoNotUseDPrintExplicitLogging = true;
}

inline void DPrintFlagOn(int flag)
{
	if (DoNotUseDPrintFlag)
		DoNotUseDPrintFlag[flag] = true;
}

inline void DPrintFlagOff(int flag)
{
	if (DoNotUseDPrintFlag)
		DoNotUseDPrintFlag[flag] = false;
}

inline void DPrintFlagToggle(int flag)
{
	if (DoNotUseDPrintFlag)
		DoNotUseDPrintFlag[flag] = !DoNotUseDPrintFlag[flag];
}

inline void DPrintFlagSet(int flag, bool setting)
{
	if (DoNotUseDPrintFlag)
		DoNotUseDPrintFlag[flag] = setting;
}

inline bool DPrintFlag(int flag)
{
	if (DoNotUseDPrintFlag)
		return DoNotUseDPrintFlag[flag];
	return 0;
}

inline void DPrintClear(void)
{
	if (DoNotUseDPrintFlag)
		DoNotUseDPrintClear();
}

#define DPRINT(b)          (DoNotUseDPrintFlag ? DoNotUseDPrint b : NOP)
#define DPRINT_FLAG(a, b)  ((DoNotUseDPrintFlag && DoNotUseDPrintFlag[a]) ? DoNotUseDPrint b : NOP)
#define DPRINT_LOG(b)      (DoNotUseDPrintFlag ? (*DoNotUseDPrintExplicitLogging = true, DoNotUseDPrint b) : NOP )

// ======================================================================
#else

inline void DPrintPauseOn(void)
{
}

inline void DPrintPauseOff(void)
{
}

inline void DPrintPauseToggle(void)
{
}

inline void DPrintLogOn(void)
{
}

inline void DPrintLogOff(void)
{
}

inline void DPrintLogToggle(void)
{
}

inline void DPrintLogNext(void)
{
}

inline void DPrintFlagOn(int)
{
}

inline void DPrintFlagOff(int)
{
}

inline void DPrintFlagToggle(int)
{
}

inline void DPrintFlagSet(int, bool)
{
}

inline int  DPrintFlag(int)
{
	return 0;
}

inline void DPrintClear(void)
{
}

#define DPRINT(b)          NOP
#define DPRINT_FLAG(a, b)  NOP
#define DPRINT_LOG(b)      NOP

// ======================================================================

#endif
#endif
